@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 from django.db import models
+from django.contrib.auth import get_user_model
 
 
 class ORM(object):
@@ -11,3 +12,5 @@ class ORM(object):
             setattr(self, appname, app)
 
 orm = ORM()
+
+User = get_user_model()
